Crate type_proof_macros

Crate type_proof_macros 

Macros for the type-proof crate.

The macros are re-exported in type-proof, so it’s recommended to just use them through that.

Macros

N
Creates a typed version of the given natural number.
P
Creates a typed propositional variable with the given natural number as the index.