P!() { /* proc-macro */ }Expand description
Creates a typed propositional variable with the given natural number as the index.
Useful for creating propositional variables with indices beyond the hard-coded type aliases.
Example
use type_proof::{
formula::{P, P3},
type_utils::assert_type_eq,
};
assert_type_eq::<P!(3), P3>();